summaryrefslogtreecommitdiffstats
path: root/libkdepim/kfileio.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /libkdepim/kfileio.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdepim/kfileio.h')
-rw-r--r--libkdepim/kfileio.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libkdepim/kfileio.h b/libkdepim/kfileio.h
index 928175b6..91552888 100644
--- a/libkdepim/kfileio.h
+++ b/libkdepim/kfileio.h
@@ -78,10 +78,10 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
* all files and folders below. If the permissions are not ok, it tries to correct
* them. If that fails then a warning with detailled information is given.
*
* @param tqparent If tqparent is 0, then the message box becomes an
* application-global modal dialog box. If tqparent
* is a widget, the message box becomes modal
* relative to tqparent.
* @param toCheck The file or folder of which the permissions should
* be checked.
* @param recursive Set to true, it will check the contents of a folder
@@ -97,7 +97,7 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
* then the permissions are not ok and it was not possible to correct
* all errors.
*/
-bool checkAndCorrectPermissionsIfPossibleWithErrorHandling( TQWidget *tqparent,
+bool checkAndCorrectPermissionsIfPossibleWithErrorHandling( TQWidget *parent,
const TQString &toCheck, const bool recursive, const bool wantItReadable,
const bool wantItWritable );
}
@@ -78,10 +78,10 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
* them. If that fails then a warning with detailled information is given.
*
- * @param tqparent If tqparent is 0, then the message box becomes an
- * application-global modal dialog box. If tqparent
+ * @param parent If parent is 0, then the message box becomes an
+ * application-global modal dialog box. If parent
* is a widget, the message box becomes modal
@@ -78,10 +78,10 @@ TQString checkAndCorrectPermissionsIfPossible( const TQString &toCheck,
* is a widget, the message box becomes modal
- * relative to tqparent.
+ * relative to parent.
* @param toCheck The file or folder of which the permissions should
* be checked.